@@ -203,12 +203,22 @@ def only_pm():
                 pass
             else:
                 await func(event)
-
         return wrapper
-
     return decorator
-#==================================================
 
+def owner_only():
+    def decorator(func):
+        @functools.wraps(func)
+        async def wrapper(event):
+            owner = Var.OWNER_ID
+            if event.sender_id == owner:
+                await func(event)
+            else:
+                pass
+        return wrapper
+    return decorator
+
+#==================================================
 is_admin = is_admin()
 is_bot_admin = is_bot_admin()
 only_groups = only_groups()
@@ -219,5 +229,5 @@ chat_creator = chat_creator()
 can_promote = can_promote()
 change_info = change_info()
 can_delete = can_delete()
-
+owner_only = owner_only()
 # =================== CONSTANT ===================
